@@ -6,7 +6,7 @@ use serde::{Deserialize, Serialize};
 
 use crate::build_system::FlatpakBuildSystem;
 use crate::format::FlatpakManifestFormat;
-use crate::source::{FlatpakSource, FlatpakSourceItem, ARCHIVE, GIT, PATCH};
+use crate::source::{FlatpakSourceItem, FlatpakSourceType};
 
 #[derive(Clone)]
 #[derive(Deserialize)]
@@ -213,10 +213,8 @@ impl FlatpakModule {
     pub fn is_patched(&self) -> bool {
         for source in &self.sources {
             if let FlatpakSourceItem::Description(sd) = source {
-                if let Some(t) = &sd.r#type {
-                    if t == PATCH {
-                        return true;
-                    }
+                if sd.get_type() == Some(FlatpakSourceType::Patch) {
+                    return true;
                 }
             }
         }
@@ -329,7 +327,7 @@ impl FlatpakModule {
                 FlatpakSourceItem::Description(d) => d,
                 FlatpakSourceItem::Path(_p) => continue,
             };
-            if source_description.get_type_name() != ARCHIVE {
+            if source_description.get_type() != Some(FlatpakSourceType::Archive) {
                 continue;
             }
 
@@ -349,7 +347,7 @@ impl FlatpakModule {
                 FlatpakSourceItem::Description(d) => d,
                 FlatpakSourceItem::Path(_p) => continue,
             };
-            if source_description.get_type_name() != GIT {
+            if source_description.get_type() != Some(FlatpakSourceType::Git) {
                 continue;
             }
 
@@ -429,8 +427,12 @@ impl FlatpakModule {
                 FlatpakSourceItem::Path(_) => continue,
             };
 
-            let source_type_name = source_description.get_type_name();
-            if crate::source::CODE_TYPES.contains(&source_type_name) {
+            let source_type = match source_description.get_type() {
+                Some(t) => t,
+                None => continue,
+            };
+
+            if source_type.is_code() {
                 code_sources_count += 1;
             }
             if code_sources_count > 1 {
@@ -564,6 +566,7 @@ pub struct FlatpakBuildOptions {
     pub no_debuginfo_compression: Option<bool>,
 
     /// This is a dictionary defining for each arch a separate build options object that override the main one.
+    #[serde(skip_serializing_if = "BTreeMap::is_empty")]
     pub arch: BTreeMap<String, FlatpakBuildOptions>,
 }
 
@@ -571,6 +574,33 @@ pub struct FlatpakBuildOptions {
 mod tests {
     use super::*;
 
+    #[test]
+    pub fn test_parse_build_options() {
+        let module_manifest = r###"
+            name: "flatpak-rs"
+            buildsystem: simple
+            cleanup: [ "*" ]
+            build-options:
+               cflags: "-O2 -g"
+               cxxflags: "-O2 -g"
+               env:
+                   V: "1"
+               arch:
+                   x86_64:
+                       cflags: "-O3 -g"
+            config-opts: []
+            sources:
+              -
+                "shared-modules/linux-audio/lv2.json"
+        "###;
+        match FlatpakModule::parse(FlatpakManifestFormat::YAML, module_manifest) {
+            Err(e) => std::panic::panic_any(e),
+            Ok(module) => {
+                assert_eq!(module.name, "flatpak-rs");
+            }
+        }
+    }
+
     #[test]
     pub fn test_parse_extra_data() {
         let module_manifest = r###"
